@@ -5,20 +5,20 @@ function(object, ...){
    items.removed <- object$items.removed
    HT <- object$HT
    method <- object$method
-   item.mean <- object$item.mean
+   Hi <- object$Hi
    J <- nrow(violations)
    I.labels <- dimnames(violations)[[1]]
-   summary.matrix <- matrix(0,nrow=J,ncol=9)
-   summary.matrix[,1] <- round(item.mean,2)
+   summary.matrix <- matrix(0,nrow=J,ncol=10)
+   summary.matrix[,1] <- round(Hi,3)
    tmax <- rep(0,J)
    if(method=="MIIO") {
-     dimnames(summary.matrix) <- list(I.labels,c("mean","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","tmax","#tsig"))
+     dimnames(summary.matrix) <- list(I.labels,c("ItemH","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","tmax","#tsig","crit"))
    }
    if(method=="MSCPM") {
-     dimnames(summary.matrix) <- list(I.labels,c("mean","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","zmax","#zsig"))
+     dimnames(summary.matrix) <- list(I.labels,c("ItemH","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","zmax","#zsig","crit"))
    }
    if(method=="IT") {
-     dimnames(summary.matrix) <- list(I.labels,c("mean","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","xmax","#xsig"))
+     dimnames(summary.matrix) <- list(I.labels,c("ItemH","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","xmax","#xsig","crit"))
    }
    k <- 0; i <- 1; j <- 2
    for(i in 1:(J-1)){for(j in (i+1):J){
@@ -37,6 +37,19 @@ function(object, ...){
    summary.matrix[,4] <- summary.matrix[,3]/summary.matrix[,2]
    summary.matrix[,7] <- summary.matrix[,6]/summary.matrix[,2]
    summary.matrix[,8] <- tmax
+   Crit <- 50 * (.30 - summary.matrix[,1]) + 
+           sqrt(summary.matrix[,3]) + 
+           100 * summary.matrix[,4]  + 
+           100 * summary.matrix[,5]  + 
+           10 * sqrt(summary.matrix[,6]) + 
+           1000 * summary.matrix[,7]  + 
+           5 * summary.matrix[,8]  + 
+           10 * sqrt(summary.matrix[,9])  + 
+           100 * summary.matrix[,9]/summary.matrix[,2]
+   Crit[summary.matrix[,3]==0] <- 0
+   summary.matrix[,10] <- floor(Crit)
+   summary.matrix[,c(1:6,8:10)] <- round(summary.matrix[,c(1:6,8:10)],2)
+   summary.matrix[,c(7)] <- round(summary.matrix[,c(7)],4)
    
-   return(list(method = method, item.summary = round(summary.matrix,2), backward.selection= violations, HT=HT))
+   return(list(method = method, item.summary = summary.matrix, backward.selection= violations, HT=HT))
 }
